========== Claun help ========== Group entity ================== :Author: Jiri Chadima :Version: 2012/04/18 Description ----------- Groups are used to authorize users to access certain server functionality, for particular documentation, see server modules (like environment). A full example document with group definition can be seen in the groups.json_ file. Groups are stored in one document. Some fields in the document are generated by the server. They are described in the appropriate module. The list here is only informative and is used to fill dropdowns in the user form. Most important groups are **all** and **admin**. :all: Every user has to have this group. It enables basic personalized interaction with the server. :admin: User in **admin** group can access all parts of the administration interface. Form fields ---------------- - **Name** - Basically any string. .. _groups.json: groups.json